"""Recipe period

Revision ID: ef630341157b
Revises: 0bfb24f16ef2
Create Date: 2022-07-27 16:02:25.375687

"""
import uuid
from alembic import op
import sqlalchemy as sa
from sqlalchemy import column, func, table, text
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = 'ef630341157b'
down_revision = '0bfb24f16ef2'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('periods',
    sa.Column('id', postgresql.UUID(as_uuid=True), nullable=False),
    sa.Column('valid_from', sa.Date(), nullable=False),
    sa.Column('valid_till', sa.Date(), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_periods'))
    )
    p = table(
        "periods",
        column("id", postgresql.UUID()),
        column("valid_from", sa.Date()),
        column("valid_till", sa.Date()),
    )
    op.create_exclude_constraint(
        "uq_periods_valid_from",
        "periods",
        (func.daterange(p.c.valid_from, p.c.valid_till, text("'[]'")), "&&"),
    )
    op.execute(
        p.insert().values(
            id='76662d3f-d5ef-4d51-bbca-909d0b0242d9',
            valid_from="01-Oct-2021",
            valid_till="31-Oct-2021",
        )
    )
    r = table(
        "recipes",
        column("period_id", postgresql.UUID()),
    )
    op.add_column('recipes', sa.Column('period_id', postgresql.UUID(as_uuid=True), nullable=True))
    op.execute(r.update().values(period_id='76662d3f-d5ef-4d51-bbca-909d0b0242d9'))
    op.alter_column("recipes", "period_id", existing_type=postgresql.UUID(), nullable=False)
    op.drop_constraint("uq_recipes_sku_id", "recipes", type_="unique")
    op.create_unique_constraint(op.f('uq_recipes_sku_id'), 'recipes', ['sku_id', 'period_id'])
    op.create_foreign_key(op.f('fk_recipes_period_id_periods'), 'recipes', 'periods', ['period_id'], ['id'])
    op.drop_column('recipes', 'valid_till')
    op.drop_column('recipes', 'valid_from')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('recipes', sa.Column('valid_from', sa.DATE(), autoincrement=False, nullable=False))
    op.add_column('recipes', sa.Column('valid_till', sa.DATE(), autoincrement=False, nullable=False))
    op.drop_constraint(op.f('fk_recipes_period_id_periods'), 'recipes', type_='foreignkey')
    op.drop_constraint(op.f('uq_recipes_sku_id'), 'recipes', type_='unique')
    op.drop_column('recipes', 'period_id')
    op.drop_table('periods')
    # ### end Alembic commands ###
